@@ -64,6 +64,9 @@ def export_course(export_path, course, settings=None):
         ### Usage example:
 
         ```python
+        from librelingo_yaml_loader import load_course
+        from librelingo_json_export.export import export_course
+
         course = load_course("./courses/french-from-english")
         export_course("./apps/web/src/courses/french-from-english", course)
         ```
